aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Transforms
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2004-10-16 18:06:43 +0000
committerChris Lattner <sabre@nondot.org>2004-10-16 18:06:43 +0000
commitc8717b1624bfdbca3183de1317be2f92a65106e5 (patch)
tree31faec89be6513371d2d95de09cc187a0d25f12c /include/llvm/Transforms
parent7eb8a523320d05d9318c957c9840cfbde3cf5b6d (diff)
downloadexternal_llvm-c8717b1624bfdbca3183de1317be2f92a65106e5.zip
external_llvm-c8717b1624bfdbca3183de1317be2f92a65106e5.tar.gz
external_llvm-c8717b1624bfdbca3183de1317be2f92a65106e5.tar.bz2
Add support for the unreachable instruction
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@17039 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/Transforms')
-rw-r--r--include/llvm/Transforms/Utils/UnifyFunctionExitNodes.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/llvm/Transforms/Utils/UnifyFunctionExitNodes.h b/include/llvm/Transforms/Utils/UnifyFunctionExitNodes.h
index 590d510..6202f85 100644
--- a/include/llvm/Transforms/Utils/UnifyFunctionExitNodes.h
+++ b/include/llvm/Transforms/Utils/UnifyFunctionExitNodes.h
@@ -23,18 +23,19 @@
namespace llvm {
struct UnifyFunctionExitNodes : public FunctionPass {
- BasicBlock *ReturnBlock, *UnwindBlock;
+ BasicBlock *ReturnBlock, *UnwindBlock, *UnreachableBlock;
public:
UnifyFunctionExitNodes() : ReturnBlock(0), UnwindBlock(0) {}
// We can preserve non-critical-edgeness when we unify function exit nodes
virtual void getAnalysisUsage(AnalysisUsage &AU) const;
// getReturn|UnwindBlock - Return the new single (or nonexistant) return or
// unwind basic blocks in the CFG.
//
BasicBlock *getReturnBlock() const { return ReturnBlock; }
BasicBlock *getUnwindBlock() const { return UnwindBlock; }
+ BasicBlock *getUnreachableBlock() const { return UnreachableBlock; }
virtual bool runOnFunction(Function &F);
};
@@ -23,18 +23,19 @@
// We can preserve non-critical-edgeness when we unify function exit nodes
virtual void getAnalysisUsage(AnalysisUsage &AU) const;
- // getReturn|UnwindBlock - Return the new single (or nonexistant) return or
- // unwind basic blocks in the CFG.
+ // getReturn|Unwind|UnreachableBlock - Return the new single (or nonexistant)
+ // return, unwind, or unreachable basic blocks in the CFG.
//
BasicBlock *getReturnBlock() const { return ReturnBlock; }